###############################################################################################
##   These are Specctra command examples which you can use in your routing dofiles. 	     ##
##   You will find many examples of ways to control the router to meet your requirements.    ##
##   Please read the Specctra User's Reference manual for details on any of the commands.    ##
##   The use of specific commands and command values should be customized to meet your       ##
##   specific requirements. You can find additional dofile examples at the end of your       ##
##   Training Guide.                                                                         ##
###############################################################################################
## Global Setup                                                                              ##
###############################################################################################
unit mil
bestsave on .\best.wir
status_file .\route.sts
grid wire 1
grid via 1
###############################################################################################
## Router Rule Examples (units in mils)                                                      ##
###############################################################################################
rule pcb (clearance 10 (type smd_via_same_net))
rule pcb (clearance 10 (type via_via_same_net))
rule pcb (clearance 10 (type smd_to_turn_gap))
rule pcb (clearance 10 (type pad_to_turn_gap))
rule pcb (clearance 10 (type buried_via_gap))
rule pcb (clearance 10 (type antipad_gap))
rule pcb (via_at_smd on)
change smd_escape 200
define (class clocks clk1 clk33 clk2)
define (class_class analog digital (rule (parallel_segment (gap 5)(limit 50))))
define (net clk2(order U1-1 U2-3 U2-9 U4-4))
define (net clk1(comp_order U1 U2 U4))
define (net clk1(fromto U1-1 (virtual_pin VP1)(circuit (length 350 300)))
	(fromto (virtual_pin VP1) U2-3 (circuit (length 2000 1950)))
	(fromto (virtual_pin VP1) U4-4 (circuit (length 2000 1950)))
	)
define (net clk1(fromto U1-1 (virtual_pin VP1(position 3500 4700))(circuit (length 350 300)))
	(fromto (virtual_pin VP1) U2-3 (circuit (length 2000 1950)))
	(fromto (virtual_pin VP1) U4-4 (circuit (length 2000 1950)))
	)
define (group g1 fromto U2-3)(fromto U15-6 U22-4))
define (group g2 fromto U1-1 U2-3)(fromto U15-6 U22-4))
define (group_set g1 g2(circuit match_group_length on(tolerance 100)))
define (pair (nets sig1a sig1b (gap 5)))
circuit class clocks (match_net_length on (ratio_tolerance .10))
circuit net clk1 (shield on (use_net gnd))
circuit net clk1 (length 1.2 -1 (type ratio))
circuit group g1 (match_fromto_length on(tolerance 10))
rule pcb (reorder starburst)
rule pcb (tjunction on)
rule pcb (junction_type term_only)
rule layer sig1 (limit_way 150)
rule layer sig2 (clearance 5 (type wire_wire))
rule net clk1 (shield_width 5)
rule net clk1 (shield_gap 6)
rule class clocks (reorder daisy)
rule class clocks (max_stub 300)
rule class clocks (parallel_segment (gap 10)(limit 1000))
rule class analog (parallel_noise (gap 5)(threshold 50)(weight .14))
rule class clocks (max_noise 400)
rule class clocks (parallel_noise (gap 5)(threshold 50)(weight .04))
rule group g1 (limit_vias 1)
rule group_set grpset1 (limit_vias 1)
rule region (width 4)

###############################################################################################
## Router Costing Examples - (multiple commands per line separated by semicolons)            ##
###############################################################################################
cost off_grid forbidden; cost side_exit forbidden; cost off_center forbidden
cost way 50; tax way 10
cost via low; tax via .8
cost layer SIG_2 high (type way)
cost layer SIG_2 high (type length); tax layer SIG_1 2
cost squeeze low; tax squeeze .5
cost cross 25; tax cross 1.3
###############################################################################################
## Fanout Examples - TRY some of the following strategies to fanout your SMD's               ##
############################################################################################### 
fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)(smart_via_grid two_wire_between)
# =====================================================================================#
fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)(smart_via_grid one_wire_between)
# =====================================================================================#
grid via 1
rule pcb (clearance 18(type via_via))
fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)
# =====================================================================================#
tax squeeze .2
select comp (property (type small))
fanout 3 (pin_type power)(pin_share on)(via_share on)(share_len 100)(max_len 150)
unsel all comp
fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)
tax squeeze 1
# =====================================================================================#
tax squeeze .2
fanout 3 (pin_type power)(pin_share on)(via_share on)(share_len 100)(max_len 150)
fanout 5 (pin_type signal)(pin_share on)(via_share on)(share_len 100)
tax squeeze 1
# =====================================================================================#
tax squeeze .2
cost off_center 0
fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)
tax squeeze 1
cost off_center -1
###############################################################################################
## Routing Commands                                                                          ##
############################################################################################### 
route 25
clean 2
route 50 16
clean 3
###############################################################################################
## Optional  - If there are conflicts left either cleanup by hand or use one of following;    ##
###############################################################################################
filter 5
delete conflicts
write routes .\premiter.rte
###############################################################################################
## Mfg. Commands & Test Prep                                                                 ##
###############################################################################################
testpoint
testpoint (center_center 100)((image_outline_clearance 40)(pin_allow on)(use_via testvia)
spread (extra 4 1)
spread (extra 2 (type wire_wire wire_smd))
center
###############################################################################################
## Miter Commands - Try one of the following miter strategies                                ##
###############################################################################################
miter
# =====================================================================================#
miter (slant 1000)
miter (slant 500)
miter (slant 100)
miter (pin 50)
miter (bend 16 2)
# =====================================================================================#
miter (slant 1000)
miter (pin 25)
miter (pin 50)
miter (pin 75)
miter (pin 100)
miter (pin 125)
miter (pin 150)
miter (pin 175)
miter (pin 200)
miter (pin 250)
miter (pin 300)
miter (bend 1000 50)
miter (bend 50 5)
miter (bend 5 1)
# =====================================================================================#
###############################################################################################
## Final save and status report for completed design                                         ##
###############################################################################################
write routes .\final.rte
report status .\final.sts







