###############################################################################################
##   This SPECCTRA dofile demonstrates how the basic dofile can be customized.               ##
##   You will find many examples of ways to control the router to meet your requirements.    ##
##   Please read the Autorouter Command Reference for details on any of the commands.	     ##
##   The use of specific commands and command values should be customized to meet your       ##
##   specific design requirements.                                                           ##
##                                     Good Luck!!                                           ##                    	
###############################################################################################
## Global Setup	                                                                             ##
###############################################################################################
# =====================================================================================#
## Setup basic units for dofile commands (mil, inch, mm, cm, um)
unit mil
# =====================================================================================#
## Save a wires after each router pass if completion rate has improved
bestsave on .\best.wir
# =====================================================================================#
## Start a route status file to monitor the routing progress
status_file .\route.sts
# =====================================================================================#
## Set wire grid
grid wire 1	
# =====================================================================================#
## Read in master rules dofile for design - this is an example of a nested dofile.
## It is recommended to nest rule commands in a separate dofile. This practice simplifies
## the re-establishment of rules when viewing routing results in future SPECCTRA sessions,
## and facilitates ECO runs.
do design_rules.do	
# =====================================================================================#
###############################################################################################
## Router Controls                                                                           ##
## The following rules are contained in design_rules.do.  They control the router for        ##
## specific design requirements                                                              ##
###############################################################################################
# =====================================================================================#
## Sets the minimum clearance from the smd pad to the first via on the same net	
# rule pcb (clearance 10 (type smd_via_same_net))
# =====================================================================================#
## Sets the minimum clearance between any two vias on the same net and same layer	
# rule pcb (clearance 10 (type via_via_same_net))
# =====================================================================================#
## Sets the minimum clearance from any smd pad to the first 90-degree turn in the wire	
# rule pcb (clearance 10 (type smd_to_turn_gap))
# =====================================================================================#
## Sets the minimum clearance from any through-pin to the first 90-degree turn in the wire	
# rule pcb (clearance 10 (type pad_to_turn_gap))
# =====================================================================================#
## Sets the minimum clearance between buried vias which do not share a common layer	
# rule pcb (clearance 10 (type buried_via_gap))
# =====================================================================================#
## Sets the minimum clearance between antipads of power nets to all other antipads	
# rule pcb (clearance 10 (type antipad_gap))
# =====================================================================================#
###############################################################################################
## Router Influences	                                                                     ##
## Limit, tax, or cost commands can be applied to achieve desired routing results.           ##
## Tax is the recommended way to influence the router's behavior.                            ##
## Tax is a multiplier that increases or reduces the standard internal cost parameters       ##
## relative to the value of 1.                                                               ##
## Cost values remain fixed during routing passes until changed with a subsequent command.   ##
## Costs can be values from 0 - 100 (forbidden=100, high= 0)                                 ##
###############################################################################################
# =====================================================================================#
## Set cost for router to exit SMD pads on the long side to be forbidden	
# cost side_exit forbidden
# =====================================================================================#
## Set cost for router to exit or enter SMD pads off center to be forbidden	
# cost off_center forbidden
# =====================================================================================#
## Set cost for router to route in wrong layer direction to be high	
# cost way 50
# =====================================================================================#
## Set cost for router to use vias to be low	
# cost via low
# =====================================================================================#
## Set cost for router to route on layer SIG_1 to be high	
# cost layer SIG_1 high (type length)
# =====================================================================================#
## Set cost for router to route in wrong layer direction on layer SIG_2 to be high	
# cost layer SIG_2 high (type way)
# =====================================================================================#
## This would tax wrong way routing 10 times the default router cost	
# tax way 10
# =====================================================================================#
## This would tax the cost to create a wire_via conflict .5 times the default router cost	
# tax squeeze .5
# =====================================================================================#
## This would tax crossing conflicts 1.3 times the default router cost	
# tax cross 1.3
# =====================================================================================#
## This would tax the cost to use a via .8 times the default router cost	
# tax via .8
# =====================================================================================#
###############################################################################################
## Fanout Stage - Use one of the following strategies to fanout your SMD's                   ##
## This stage may require interactive editing to guarantee desired routing results.          ##
## Fanout should be run only when you have 4 or more signal layers.                          ##
## Using a via grid to allow 1 or 2 wires between vias is recommended to create unobstructed ##
##   routing channels                                                                        ##
############################################################################################### 
# =====================================================================================#
## This method is for low to medium density surface mount designs
## Use Smart grid to automatically set via grid for two wires between 
##  (one_wire_between can also be used)
## Run 5 passes of fanout on active pins and allows pin & via sharing within 100 mils of smd pad	
# fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)(smart_via_grid two_wire_between)
# =====================================================================================#
## This method is can be used for all types of surface mount designs
## Set via grid to allow one wire between vias; 
##   via grid = 2 x  (wire_via clearance) + wire width + via diameter
## For example; wire_via = 6, wire width = 6, via diameter = 32 ---->>>  2 x (6) + 6 + 32 = 50
grid via 50
## Run 5 passes of fanout on active pins and allows pin & via sharing within 100 mils of smd pad
fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)
# =====================================================================================#
## This method is used for dense surface mount designs with limited via sites
## Set via_via spacing to allow one wire between vias and set via grid at minimum allowed
# rule pcb (clearance 18(type via_via))
# grid via 1
## Run 5 passes of fanout on active pins and allows pin & via sharing within 100 mils of smd pad
# fanout 5 (pin_type active)(pin_share on)(via_share on)(share_len 100)
# =====================================================================================#
###############################################################################################
## Routing Stage - After fanouts and critical preroutes are complete run this stage          ##
## Monitor router progress over the first five passes to see if ;                            ##
##	*There are less than 2% unroutes after pass 1                                        ##
##	*There are no more than 5 conflicts (cross + clearance) per connection after pass 1  ##
##	*Conflict reduction is ~25 - 30% after passes 2 - 5                                  ##
## If these conditions are not met there may be problems with ;                              ##
##	*Restrictive design rules                                                            ##
##	*Protected wires                                                                     ##
##	*Incorrect routing direction                                                         ##
##	*Autorouter is via starved                                                           ##
##	*Not enough signal layers                                                            ##
############################################################################################### 
# =====================================================================================#
## Route 25 passes
route 25
# =====================================================================================#
## Run two clean passes to reroute every wire
clean 2
# =====================================================================================#
## Route 50 passes starting at cost schedule for pass 16.  
## After you have run at least 15 - 25 passes you should always start routing at pass 16
route 50 16
# =====================================================================================#
## Final Cleanup
clean 3
# =====================================================================================#
###############################################################################################
## Optional  - If there are conflicts left either cleanup manually or use one of following;  ##
###############################################################################################
# =====================================================================================#
## Run filter command to remove conflicts and leave as few unroutes as possible
# filter 5
# =====================================================================================#
## Run delete conflicts to remove wires with conflicts and leave unroutes to add by hand
# delete conflicts
# =====================================================================================#
## Save routes before miter process so you can try different miter strategies
write routes .\premiter.rte
# =====================================================================================#
###############################################################################################
## Optional  - Same net check to find minor mfg routing problems                             ##
###############################################################################################
# =====================================================================================#
## Turn same net check on so same net drc violations are checked (default is off)
set same_net_checking on
# =====================================================================================#
## Check design for same net conflicts
check
# =====================================================================================#
## Run 5 route passes to fix any same net conflicts
route 5 16
# =====================================================================================#
###############################################################################################
## Optional - Testability                                                                    ##
###############################################################################################
# =====================================================================================#
## Run testpoint command to add testpoints
testpoint (side back)(center_center 100)(image_outline_clearance 40)(pin_allow on)(use_via testvia)
# =====================================================================================#
## Run 3 clean passes to remove any redundant vias created by testpoint
clean 3
# =====================================================================================#
###############################################################################################
## Final Miter/Mfg. Stage - Run after design is completed or ready to go back to host cad    ##
###############################################################################################
# =====================================================================================#
## Spread wires for mfg.  Do not use this if using FST rules.
spread (extra 4 1)
# =====================================================================================#
## Center wires between pads
center
# =====================================================================================#
## Change 90 degree corners to 45 (See User's Reference for command options)
# miter
## Using some miter options helps get desired routing results
miter (slant 1000); miter (slant 500); miter (slant 100)
miter (pin 50)
miter (bend 16 2)
# =====================================================================================#
## Save completed routes
write routes .\final.rte
# =====================================================================================#
## Report complete session results
report status .\final.sts
